@@ -672,9 +672,12 @@ def main():
     parser.add_argument('dyagram_args', nargs='*')
 
     args = parser.parse_args()
+
+    verbose = False
     if '-v' or '--verbose' in args.dyagram_args:
         verbose = True
 
+
     if args.dyagram_args[0].lower() == "init":
         from dyagram.initialize import initialize
         initialize.main()
@@ -683,8 +686,9 @@ def main():
 
     if args.dyagram_args[0].lower() == "discover":
         print("\n\n-- DyaGram Discovering Started --\n")
-        dy = dyagram()
+        dy = dyagram(verbose=verbose)
         dy.discover()
+
         print("\n\n-- DyaGram Discovering Completed --\n")
 
     if args.dyagram_args[0].lower() == "site":
